@@ -1,13 +1,13 @@
 --[[
 
-File l3build-help.lua Copyright (C) 2018,2020,2021 The LaTeX Project
+File l3build-help.lua Copyright (C) 2018-2025 The LaTeX Project
 
 It may be distributed and/or modified under the conditions of the
 LaTeX Project Public License (LPPL), either version 1.3c of this
 license or (at your option) any later version.  The latest version
 of this license is in the file
 
-   http://www.latex-project.org/lppl.txt
+   https://www.latex-project.org/lppl.txt
 
 This file is part of the "l3build bundle" (The Work in LPPL)
 and all files in that bundle must be distributed together.
@@ -27,7 +27,7 @@ local match  = string.match
 local rep    = string.rep
 local sort   = table.sort
 
-local copyright = "Copyright (C) 2014-2021 The LaTeX Project\n"
+local copyright = "Copyright (C) 2014-2025 The LaTeX Project\n"
 
 function version()
   print(
@@ -59,7 +59,7 @@ function help()
   if not (match(arg[0], "l3build%.lua$") or match(arg[0],"l3build$")) then
     scriptname = arg[0]
   end
-  print("usage: " .. scriptname .. " <target> [<options>] [<names>]")
+  print("\nUsage: " .. scriptname .. " <target> [<options>] [<names>]")
   print("")
   print("Valid targets are:")
   local longest,t = setup_list(target_list)
